@@ -1,3 +1,7 @@
+from dataclasses import dataclass
+
+
+@dataclass
 class ContentTier:
     uuid: str
     dev_name: str
@@ -13,6 +17,3 @@ class ContentTier:
         self.display_icon = data.get("displayIcon")
         self.asset_path = data.get("assetPath")
         self.raw_data = data
-
-    def __str__(self):
-        return str(self.raw_data)
