@@ -3,6 +3,7 @@ class Endpoints:
     BASE = "https://valorant-api.com/v1/"
     Agents = BASE + "agents"
     Buddies = BASE + "buddies"
+    BuddyLevels = Buddies + "/levels"
     Bundles = BASE + "bundles"
     ContentTiers = BASE + "contenttiers"
     Currencies = BASE + "currencies"
@@ -13,6 +14,7 @@ class Endpoints:
     PlayerTitles = BASE + "playertitles"
     Seasons = BASE + "seasons"
     Sprays = BASE + "sprays"
+    SprayLevels = Sprays + "/levels"
     Themes = BASE + "themes"
     Weapons = BASE + "weapons"
     Version = BASE + "version"
@@ -23,3 +25,4 @@ class Endpoints:
     WeaponSkinLevels = Weapons + "/skinlevels"
     Contracts = BASE + "contracts"
     Events = BASE + "events"
+    Gears = BASE + "gear"
