@@ -6,10 +6,16 @@ import aiohttp
 import requests
 from aiohttp import ClientSession
 from requests import Session
+import copy
 
 from .exceptions import *
 
 
+def override_params(par1, par2):
+    if par2 is not None:
+        par1.update(par2)
+    return par1
+
 class SyncClient:
     headers: dict = {}
     params: dict = {}
@@ -26,8 +32,8 @@ class SyncClient:
             self.headers = headers
             self.session = requests.Session()
 
-    def get(self, url: str):
-        response = self.session.get(url, params=self.params, headers=self.headers)
+    def get(self, url: str, params: dict = None) -> dict:
+        response = self.session.get(url, params=override_params(copy.copy(self.params), params), headers=self.headers)
 
         try:
             data = response.json()
@@ -65,9 +71,8 @@ class AsyncClient:
         loop = asyncio.get_event_loop()
         loop.run_until_complete(self.session.close())
 
-    async def get(self, url: str):
-        # async with aiohttp.ClientSession() as session:
-        async with self.session.get(url, params=self.params, headers=self.headers) as response:
+    async def get(self, url: str, params: dict = None) -> dict:
+        async with self.session.get(url, params=override_params(copy.copy(self.params), params), headers=self.headers) as response:
             try:
                 data = await response.json()
             except aiohttp.ContentTypeError:
