@@ -1,4 +1,28 @@
 from dataclasses import dataclass
+from typing import List
+
+
+
+@dataclass
+class Location:
+    x: float
+    y: float
+
+    def __init__(self, data: dict) -> None:
+        self.x = data.get('x')
+        self.y = data.get('y')
+
+
+@dataclass
+class Callout:
+    region_name: str
+    super_region_name: str
+    location: Location
+
+    def __init__(self, data: dict) -> None:
+        self.region_name = data.get("regionName")
+        self.super_region_name = data.get("superRegionName")
+        self.location = Location(data.get("location"))
 
 
 @dataclass
@@ -15,6 +39,7 @@ class Map:
     y_multiplier: float
     x_scalar_to_add: float
     y_scalar_to_add: float
+    callouts: List[Callout]
     raw_data: dict
 
     def __init__(self, data: dict) -> None:
@@ -30,4 +55,5 @@ class Map:
         self.y_multiplier = data.get("yMultiplier")
         self.x_scalar_to_add = data.get("xScalarToAdd")
         self.y_scalar_to_add = data.get("yScalarToAdd")
+        self.callouts = [Callout(x) for x in data.get("callouts")] if data.get("callouts") else []
         self.raw_data = data
